# README

The `requirements-*.txt` files within this directory define the Python environment used for the *continuous integration tests* of this package. Note: For instructions on how to install the package for regular use, please see the documentation.

The consistency of the requirements defined here with the dependencies defined in the `pyproject.toml` file is checked automatically as part of the continuous integration workflow.

https://github.com/aiidateam/aiida-core/wiki/AiiDA-Dependency-Management
